@@ -14,7 +14,7 @@ class Location(TimetrackingBaseModel):
     uuid = models.UUIDField(primary_key=True, default=uuid.uuid4)
     device_user = models.ForeignKey(DeviceUser, on_delete=models.CASCADE)
     bat = models.CharField(max_length=256, unique=True)
-    raw_date = models.PositiveIntegerField()
+    raw_date = models.PositiveBigIntegerField()
     lat = models.CharField(max_length=256, unique=True)
     lon = models.CharField(max_length=256, unique=True)
     provider = models.CharField(max_length=256, unique=True)
